@@ -615,6 +615,8 @@ void Bayonne::down(void)
 ScriptCompiler *Bayonne::reload(void)
 {
 	static Mutex lock;
+	char buffer[32];
+	const char *cp;
 
 	ScriptCompiler *img;
 
@@ -634,6 +636,23 @@ ScriptCompiler *Bayonne::reload(void)
 		img->loadPrefix("config", "~bayonne/config");
 #endif
 
+#ifdef	SCRIPT_DEFINE_TOKENS
+	const char *const *list = server->getList("definitions");
+	img->compileDefinitions("site.def");
+	while(list && *list)
+	{
+		img->compileDefinitions(*list);
+		++list;
+	}
+	cp = server->getLast("location");
+	if(cp)
+	{
+		snprintf(buffer, sizeof(buffer), "macros-%s.def", cp);
+		img->compileDefinitions(buffer);
+	}
+	img->compileDefinitions("macros.def");
+#endif
+
 	ScriptBinder::rebuild(img);
 	img->commit();
 	lock.leave();
