@@ -78,9 +78,13 @@ BayonneDriver::~BayonneDriver()
 	}
 }
 
-unsigned BayonneDriver::getRegistration(regauth_t *data, unsigned count)
+const char *BayonneDriver::remapDriver(const char *id)
 {
-        return 0;
+#ifndef	WIN32
+	if(!stricmp(id, "sip"))
+		return NAME_SIP_DRIVER;
+#endif
+	return id;
 }
 
 void BayonneDriver::del(BayonneSession *session)
@@ -261,9 +265,9 @@ BayonneDriver *BayonneDriver::loadDriver(const char *id)
 	char prefixbuf[256];
 	if(!prefix && provision_test)
 	{
-		snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s/.libs", SOURCE_FILES, id);
+		snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s/.libs", SOURCE_FILES, remapDriver(id));
 		if(!isDir(prefixbuf))
-			snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s", SOURCE_FILES, id);
+			snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s", SOURCE_FILES, remapDriver(id));
 		prefix = prefixbuf;
 	}
 #endif
@@ -284,7 +288,7 @@ BayonneDriver *BayonneDriver::loadDriver(const char *id)
 
 	if(!canAccess(path))
 	{
-		errlog("access", "cannot load %s", path);
+		errlog("access", "cannot load driver %s", path);
 		return NULL;
 	}
 
