@@ -604,8 +604,8 @@ const char *Checks::chkRecord(Line *line, ScriptImage *img)
 	if(!getOption(line, &idx))
 		return "requires one file argument";
 
-	if(getOption(line, &idx))
-		return "uses only one file argument";
+	if(getOption(line, &idx) && getOption(line, &idx))
+		return "uses only up to two file arguments";
 
 	return NULL;
 }
@@ -644,8 +644,8 @@ const char *Checks::chkAppend(Line *line, ScriptImage *img)
 	if(!getOption(line, &idx))
 		return "requires one file argument";
 
-	if(getOption(line, &idx))
-		return "uses only one file argument";
+	if(getOption(line, &idx) && getOption(line, &idx))
+		return "uses only up to two file arguments";
 
 	return NULL;
 }
