@@ -5,7 +5,7 @@
 #bayonne: echo "ERROR %script.error"
 #bayonne: echo "LIBEXEC RESULT %result"
 #
-# Copyright (C) 2005 Open Source Telecom Corp.
+# Copyright (C) 2005 David Sugar, Tycho Softworks
 #
 # This file is free software; as a special exception the author gives
 # unlimited permission to copy and/or distribute it, with or without
@@ -18,6 +18,8 @@
 # Basic perl script for testing of libexec subsystem and use of
 # Bayonne::Libexec perl module.
 
+print STDERR "STARTING!\n";
+
 # this is needed if test script is executed directly (outside Bayonne)
 use lib '../scripts';
 
@@ -25,10 +27,10 @@ use lib '../scripts';
 use libexec;
 
 # create $TGI instance of libexec (based on future cpan mapping...)
-$TGI = new Bayonne::Libexec;
+my($TGI) = new Bayonne::Libexec;
 
 # get tgi version, and print it (sent to stderr if in tgi). 
-$ver=$TGI->{version};
+my($ver)=$TGI->{version};
 $TGI->print("TGI VERSION $ver\n"); 
 
 # see if we are running under bayonne, or just stand-alone
@@ -46,9 +48,9 @@ $TGI->print("COMMAND RESULT $result\n");
 $TGI->print("LAST COMMAND RESULT BEFORE EXIT $TGI->{result}\n");
 $TGI->result("CODE $result");
 
-$file = $TGI->filename("tmp:edit");
+my($file) = $TGI->filename("tmp:edit");
 $TGI->print("FILE NAME $file\n");
 
-exit
+exit;
 
 
